@@ -157,3 +157,9 @@ def new_client(connection: DbConnection, log: Logger) -> Cmd[SqlClient]:
         return SqlClient(log, connection._inner._connection.cursor())
 
     return Cmd.from_cmd(_action)
+
+
+__all__ = [
+    "Query",
+    "DbConnection",
+]
