@@ -1,6 +1,13 @@
+from __future__ import (
+    annotations,
+)
+
 from dataclasses import (
     dataclass,
 )
+from deprecated import (
+    deprecated,
+)
 from enum import (
     Enum,
 )
@@ -62,24 +69,29 @@ class DbConnection:
     def commit(self) -> Cmd[None]:
         return Cmd.from_cmd(lambda: cast(None, self._inner._connection.commit()))  # type: ignore[no-untyped-call]
 
+    @staticmethod
+    def connect(
+        db_id: DatabaseId,
+        creds: Credentials,
+        readonly: bool,
+        isolation: IsolationLvl,
+    ) -> Cmd[DbConnection]:
+        def _action() -> DbConnection:
+            connection = postgres.connect(
+                dbname=db_id.db_name,
+                user=creds.user,
+                password=creds.password,
+                host=db_id.host,
+                port=db_id.port,
+            )
+            connection.set_session(readonly=readonly)  # type: ignore[no-untyped-call]
+            connection.set_isolation_level(isolation.value)  # type: ignore[no-untyped-call]
+            draft = _DbConnection(connection)
+            return DbConnection(draft)
 
-def connect(
-    db_id: DatabaseId,
-    creds: Credentials,
-    readonly: bool,
-    isolation: IsolationLvl,
-) -> Cmd[DbConnection]:
-    def _action() -> DbConnection:
-        connection = postgres.connect(
-            dbname=db_id.db_name,
-            user=creds.user,
-            password=creds.password,
-            host=db_id.host,
-            port=db_id.port,
-        )
-        connection.set_session(readonly=readonly)  # type: ignore[no-untyped-call]
-        connection.set_isolation_level(isolation.value)  # type: ignore[no-untyped-call]
-        draft = _DbConnection(connection)
-        return DbConnection(draft)
+        return Cmd.from_cmd(_action)
 
-    return Cmd.from_cmd(_action)
+
+connect = deprecated(reason="Use DbConnection.connect instead")(
+    DbConnection.connect
+)
