@@ -1,6 +1,13 @@
+from __future__ import (
+    annotations,
+)
+
 from dataclasses import (
     dataclass,
 )
+from deprecated import (
+    deprecated,
+)
 from fa_purity.frozen import (
     FrozenDict,
 )
@@ -10,13 +17,10 @@ from psycopg2.sql import (
 )
 from typing import (
     cast,
-    Optional,
 )
 
 
-def _purifier(
-    statement: str, identifiers: FrozenDict[str, Optional[str]]
-) -> SQL:
+def _purifier(statement: str, identifiers: FrozenDict[str, str]) -> SQL:
     raw_sql = SQL(statement)
     safe_args = FrozenDict(
         {key: Identifier(value) for key, value in identifiers.items()}
@@ -24,6 +28,10 @@ def _purifier(
     return cast(SQL, raw_sql.format(**safe_args))  # type: ignore[no-untyped-call]
 
 
+def _pretty(raw: str) -> str:
+    return " ".join(raw.strip(" \n\t").split())
+
+
 @dataclass(frozen=True)
 class _Query:
     statement: SQL
@@ -33,18 +41,18 @@ class _Query:
 class Query:
     _inner: _Query
 
+    @staticmethod
+    def new_query(stm: str) -> Query:
+        draft = _Query(SQL(_pretty(stm)))
+        return Query(draft)
 
-def _pretty(raw: str) -> str:
-    return " ".join(raw.strip(" \n\t").split())
+    @staticmethod
+    def dynamic_query(stm: str, identifiers: FrozenDict[str, str]) -> Query:
+        draft = _Query(_purifier(_pretty(stm), identifiers))
+        return Query(draft)
 
 
-def new_query(stm: str) -> Query:
-    draft = _Query(SQL(_pretty(stm)))
-    return Query(draft)
-
-
-def dynamic_query(
-    stm: str, identifiers: FrozenDict[str, Optional[str]]
-) -> Query:
-    draft = _Query(_purifier(_pretty(stm), identifiers))
-    return Query(draft)
+new_query = deprecated(reason="Use Query.new_query instead")(Query.new_query)
+dynamic_query = deprecated(reason="Use Query.dynamic_query")(
+    Query.dynamic_query
+)
