@@ -55,7 +55,6 @@ from redshift_client.table.core import (
 from typing import (
     Callable,
     Dict,
-    Optional,
     TypeVar,
 )
 
@@ -198,7 +197,7 @@ class TableClient:
         stm = f"""
             INSERT INTO {{schema}}.{{table}} ({_fields}) VALUES %s
         """
-        identifiers: Dict[str, Optional[str]] = {
+        identifiers: Dict[str, str] = {
             "schema": table_id.schema.name,
             "table": table_id.name,
         }
@@ -212,7 +211,7 @@ class TableClient:
         stm = """
             ALTER TABLE {schema}.{table} RENAME TO {new_name}
         """
-        identifiers: Dict[str, Optional[str]] = {
+        identifiers: Dict[str, str] = {
             "schema": table_id.schema.name,
             "table": table_id.name,
             "new_name": new_name,
@@ -226,7 +225,7 @@ class TableClient:
         stm = f"""
             DROP TABLE {{schema}}.{{table}} {_cascade}
         """
-        identifiers: Dict[str, Optional[str]] = {
+        identifiers: Dict[str, str] = {
             "schema": table_id.schema.name,
             "table": table_id.name,
         }
@@ -246,7 +245,7 @@ class TableClient:
             ADD COLUMN {{column_name}}
             {_encode_data_type(column.column.data_type)} DEFAULT %(default_val)s
         """
-        identifiers: Dict[str, Optional[str]] = {
+        identifiers: Dict[str, str] = {
             "table_schema": table_id.schema.name,
             "table_name": table_id.name,
             "column_name": column.id_obj.name,
@@ -296,7 +295,7 @@ class TableClient:
             ]
         )
         stm = f"CREATE TABLE {not_exists} {{schema}}.{{table}} ({fields_template}{pkeys_template})"
-        identifiers: Dict[str, Optional[str]] = {
+        identifiers: Dict[str, str] = {
             "schema": table_id.schema.name,
             "table": table_id.name,
         }
@@ -317,7 +316,7 @@ class TableClient:
                 LIKE {blueprint_schema}.{blueprint_table}
             )
         """
-        identifiers: Dict[str, Optional[str]] = {
+        identifiers: Dict[str, str] = {
             "new_schema": new_table.schema.name,
             "new_table": new_table.name,
             "blueprint_schema": blueprint.schema.name,
@@ -337,7 +336,7 @@ class TableClient:
             ALTER TABLE {target_schema}.{target_table}
             APPEND FROM {source_schema}.{source_table}
         """
-        identifiers: Dict[str, Optional[str]] = {
+        identifiers: Dict[str, str] = {
             "source_schema": source.schema.name,
             "source_table": source.name,
             "target_schema": target.schema.name,
